@@ -2,7 +2,9 @@
 ##' @export
 merge.tbl_tree <- function(x, y, ...) {
     res <- NextMethod()
-    class(res) <- class(x)
+    if (valid.tbl_tree2(res)){
+        res <- add_class(res, 'tbl_tree')
+    }
     return(res)
 }
 
